@@ -1,6 +1,6 @@
 setClassUnion(".OptionalPOSIXct", c("POSIXct","NULL"))
 lapply(lapply(c('url','file','gzfile','unz','pipe','fifo'),c,'connection'), setOldClass,   where = environment())
-
+setOldClass("ltraj")
 setClass(Class = ".MoveGeneral",
 	 representation = representation(
 					 dateCreation = "POSIXct",
@@ -51,10 +51,14 @@ setClass(Class='.unUsedRecordsStack',contains='.unUsedRecords',# maybe at somest
 		 if(length(object@trackIdUnUsedRecords)!=nrow(object@dataUnUsedRecords))
 			 stop("TrackId and data length for unused records do not match")
 		 if(length(object@timestampsUnUsedRecords)>0)
-		 if(!all(unlist(tapply(object@timestampsUnUsedRecords, list(object@trackIdUnUsedRecords, droplevels(object@sensorUnUsedRecords)),diff))>0))
+		 if(!all((diffs<-unlist(tapply(object@timestampsUnUsedRecords, list(object@trackIdUnUsedRecords, droplevels(object@sensorUnUsedRecords)),diff)))>0))
 		 {
-			 tmp<-duplicated(cbind(object@timestampsUnUsedRecords, object@trackIdUnUsedRecords, object@sensorUnUsedRecords))# made new test in check for higher speed but have this one still here for more clear reporting
+			 if(any(diffs==0)){
+		   tmp<-duplicated(cbind(object@timestampsUnUsedRecords, object@trackIdUnUsedRecords, object@sensorUnUsedRecords))# made new test in check for higher speed but have this one still here for more clear reporting
 			 stop("The data set includes double timestamps per ID in the unused records (first one:", object@trackIdUnUsedRecords[tmp][1]," ",object@sensorUnUsedRecords[tmp][1]," ",object@timestampsUnUsedRecords[tmp][1], ")")
+		   }else{
+			 stop('The data set includes un ordered timestamps in the unUsedRecordsStack')
+			   }
 		 }
 		 return(TRUE)
 	 }
@@ -140,9 +144,9 @@ setClass(Class = ".MoveTrackStack", contains = c(".MoveTrack", ".unUsedRecordsSt
 	 validity = function(object){
 		 if(length(object@trackId)!=nrow(object@coords))
 			 stop("Length of trackId does not match the number of coordinates")
-		 if(!all(unlist(tapply(object@timestamps, list(object@trackId, droplevels(object@sensor)),diff))>0))
+		 if(!all(unlist(tapply(object@timestamps, list(trackId(object), droplevels(object@sensor)),diff))>0))
 		 {
-			 tmp<-duplicated(cbind(object@timestamps, object@trackId, object@sensor))# made new test in check for higher speed but have this one still here for more clear reporting
+			 tmp<-duplicated(cbind(object@timestamps, trackId(object), object@sensor))# made new test in check for higher speed but have this one still here for more clear reporting
 			 stop("The data set includes double timestamps per ID (first one:", object@trackId[tmp][1]," ",object@sensor[tmp][1]," ",object@timestamps[tmp][1], ")")
 		 }
 		 if(any(unlist(lapply(tapply(object@timestamps,object@trackId, order),diff))!=1))
@@ -168,15 +172,15 @@ setClass(Class = ".MoveTrackStack", contains = c(".MoveTrack", ".unUsedRecordsSt
 		 	if (any(dups <- duplicated(t<-cbind(
 							  format(c(object@timestamps, object@timestampsUnUsedRecords)[s],"%Y %m %d %H %M %OS4"), 
 							  c(as.character(object@sensor), as.character(object@sensorUnUsedRecords))[s], 
-							  c(as.character(object@trackId),as.character( object@trackIdUnUsedRecords))[s]))))
+							  c(as.character(trackId(object)),as.character( object@trackIdUnUsedRecords))[s]))))
 				 stop("A timestamps of a unused record coincides with a normal timestamps")
 
 		 }
-		 if(sum(diff(as.numeric(object@trackId))!=0)!=(nrow(idData(object, drop=F))-1))
+		 if(sum(diff(as.numeric(trackId(object)))!=0)!=(nrow(idData(object, drop=F))-1))
 			 stop('The data in the MoveStack object are not grouped per individual')
-		 if(any(as.character(unique(object@trackId))!= rownames(idData(object, drop=F))))
+		 if(any(as.character(unique(trackId(object)))!= rownames(idData(object, drop=F))))
 			 stop('Order of objects in the idData is not the same as in the trackId')
-		 if(!identical(as.character(unique(object@trackId)), levels(object@trackId)))
+		 if(!identical(as.character(unique(trackId(object))), levels(object@trackId)))
 			 stop('Order of levels in the trackId should be same as order of individuals') 
 		 #this check cant work since coordinates columns are not present in data
 		# if(any(names(object@data)!=names(object@dataUnUsedRecords)))
